@@ -32,7 +32,6 @@
 #include "views/dolphinview.h"
 #include "views/viewmodecontroller.h"
 
-#include <KAbstractFileItemActionPlugin>
 #include <KActionCollection>
 #include <KFileItemActions>
 #include <KFileItemListProperties>
@@ -95,8 +94,13 @@ void DolphinContextMenu::setCustomActions(const QList<QAction*>& actions)
 DolphinContextMenu::Command DolphinContextMenu::open()
 {
     // get the context information
-    if (m_baseUrl.scheme() == QLatin1String("trash")) {
+    const auto scheme = m_baseUrl.scheme();
+    if (scheme == QLatin1String("trash")) {
         m_context |= TrashContext;
+    } else if (scheme.contains(QLatin1String("search"))) {
+        m_context |= SearchContext;
+    } else if (scheme.contains(QLatin1String("timeline"))) {
+        m_context |= TimelineContext;
     }
 
     if (!m_fileInfo.isNull() && !m_selectedItems.isEmpty()) {
@@ -184,6 +188,36 @@ void DolphinContextMenu::openTrashItemContextMenu()
     }
 }
 
+void DolphinContextMenu::addDirectoryItemContextMenu(KFileItemActions &fileItemActions)
+{
+    // insert 'Open in new window' and 'Open in new tab' entries
+
+    const KFileItemListProperties& selectedItemsProps = selectedItemsProperties();
+
+    addAction(m_mainWindow->actionCollection()->action(QStringLiteral("open_in_new_tab")));
+    addAction(m_mainWindow->actionCollection()->action(QStringLiteral("open_in_new_window")));
+
+    // Insert 'Open With' entries
+    addOpenWithActions(fileItemActions);
+
+    // set up 'Create New' menu
+     DolphinNewFileMenu* newFileMenu = new DolphinNewFileMenu(m_mainWindow->actionCollection(), m_mainWindow);
+     const DolphinView* view = m_mainWindow->activeViewContainer()->view();
+     newFileMenu->setViewShowsHiddenFiles(view->hiddenFilesShown());
+     newFileMenu->checkUpToDate();
+     newFileMenu->setPopupFiles(QList<QUrl>() << m_fileInfo.url());
+     newFileMenu->setEnabled(selectedItemsProps.supportsWriting());
+     connect(newFileMenu, &DolphinNewFileMenu::fileCreated, newFileMenu, &DolphinNewFileMenu::deleteLater);
+     connect(newFileMenu, &DolphinNewFileMenu::directoryCreated, newFileMenu, &DolphinNewFileMenu::deleteLater);
+
+     QMenu* menu = newFileMenu->menu();
+     menu->setTitle(i18nc("@title:menu Create new folder, file, link, etc.", "Create New"));
+     menu->setIcon(QIcon::fromTheme(QStringLiteral("document-new")));
+     addMenu(menu);
+
+     addSeparator();
+}
+
 void DolphinContextMenu::openItemContextMenu()
 {
     Q_ASSERT(!m_fileInfo.isNull());
@@ -198,31 +232,10 @@ void DolphinContextMenu::openItemContextMenu()
     fileItemActions.setItemListProperties(selectedItemsProps);
 
     if (m_selectedItems.count() == 1) {
+        // single files
         if (m_fileInfo.isDir()) {
-            // insert 'Open in new window' and 'Open in new tab' entries
-            addAction(m_mainWindow->actionCollection()->action(QStringLiteral("open_in_new_window")));
-            addAction(m_mainWindow->actionCollection()->action(QStringLiteral("open_in_new_tab")));
-
-            // Insert 'Open With' entries
-            addOpenWithActions(fileItemActions);
-
-            // set up 'Create New' menu
-             DolphinNewFileMenu* newFileMenu = new DolphinNewFileMenu(m_mainWindow->actionCollection(), m_mainWindow);
-             const DolphinView* view = m_mainWindow->activeViewContainer()->view();
-             newFileMenu->setViewShowsHiddenFiles(view->hiddenFilesShown());
-             newFileMenu->checkUpToDate();
-             newFileMenu->setPopupFiles(m_fileInfo.url());
-             newFileMenu->setEnabled(selectedItemsProps.supportsWriting());
-             connect(newFileMenu, &DolphinNewFileMenu::fileCreated, newFileMenu, &DolphinNewFileMenu::deleteLater);
-             connect(newFileMenu, &DolphinNewFileMenu::directoryCreated, newFileMenu, &DolphinNewFileMenu::deleteLater);
-
-             QMenu* menu = newFileMenu->menu();
-             menu->setTitle(i18nc("@title:menu Create new folder, file, link, etc.", "Create New"));
-             menu->setIcon(QIcon::fromTheme(QStringLiteral("document-new")));
-             addMenu(menu);
-
-             addSeparator();
-        } else if (m_baseUrl.scheme().contains(QLatin1String("search")) || m_baseUrl.scheme().contains(QLatin1String("timeline"))) {
+            addDirectoryItemContextMenu(fileItemActions);
+        } else if (m_context & TimelineContext || m_context & SearchContext) {
             addOpenWithActions(fileItemActions);
 
             openParentAction = new QAction(QIcon::fromTheme(QStringLiteral("document-open-folder")),
@@ -253,8 +266,9 @@ void DolphinContextMenu::openItemContextMenu()
             addSeparator();
         }
     } else {
+        // multiple files
         bool selectionHasOnlyDirs = true;
-        foreach (const KFileItem& item, m_selectedItems) {
+        for (const auto &item : qAsConst(m_selectedItems)) {
             const QUrl& url = DolphinView::openItemAsFolderUrl(item);
             if (url.isEmpty()) {
                 selectionHasOnlyDirs = false;
@@ -328,19 +342,19 @@ void DolphinContextMenu::openViewportContextMenu()
     fileItemActions.setParentWidget(m_mainWindow);
     fileItemActions.setItemListProperties(baseUrlProperties);
 
+    // Set up and insert 'Create New' menu
+    KNewFileMenu* newFileMenu = m_mainWindow->newFileMenu();
+    newFileMenu->setViewShowsHiddenFiles(view->hiddenFilesShown());
+    newFileMenu->checkUpToDate();
+    newFileMenu->setPopupFiles(QList<QUrl>() << m_baseUrl);
+    addMenu(newFileMenu->menu());
+
     // Don't show "Open With" menu items if the current dir is empty, because there's
     // generally no app that can do anything interesting with an empty directory
     if (view->itemsCount() != 0) {
         addOpenWithActions(fileItemActions);
     }
 
-    // Set up and insert 'Create New' menu
-    KNewFileMenu* newFileMenu = m_mainWindow->newFileMenu();
-    newFileMenu->setViewShowsHiddenFiles(view->hiddenFilesShown());
-    newFileMenu->checkUpToDate();
-    newFileMenu->setPopupFiles(m_baseUrl);
-    addMenu(newFileMenu->menu());
-
     QAction* pasteAction = createPasteAction();
     addAction(pasteAction);
 
@@ -382,6 +396,7 @@ void DolphinContextMenu::insertDefaultItemActions(const KFileItemListProperties&
     addAction(collection->action(KStandardAction::name(KStandardAction::Cut)));
     addAction(collection->action(KStandardAction::name(KStandardAction::Copy)));
     addAction(createPasteAction());
+    addAction(m_mainWindow->actionCollection()->action(QStringLiteral("duplicate")));
 
     addSeparator();
 
